@@ -1,6 +1,6 @@
 package Resque;
 # ABSTRACT: Redis-backed library for creating background jobs, placing them on multiple queues, and processing them later.
-$Resque::VERSION = '0.40';
+$Resque::VERSION = '0.41';
 use Moose;
 use Scalar::Util 'blessed';
 use Moose::Util::TypeConstraints;
@@ -81,9 +81,13 @@ sub blpop {
     my ( $key, $payload ) = $self->redis->blpop(( map { $self->key( queue => $_ ) } @$queues ), $timeout || 0 );
     return unless $payload;
 
+    # clean prefix added by key().
+    my $prefix  = $self->key('queue');
+    my ($queue) = $key =~ /^$prefix:(.+)$/;
+
     $self->new_job({
         payload => $payload,
-        queue   => (split(':', $key))[-1]
+        queue   => $queue
     });
 }
 
@@ -201,7 +205,7 @@ Resque - Redis-backed library for creating background jobs, placing them on mult
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
